@@ -1,26 +1,13 @@
-/***************************************************************************
- *   Copyright (C) 2012 Matthias Fuchs <mat69@gmx.net>                     *
- *                                                                         *
- *   This program is free software; you can redistribute it and/or modify  *
- *   it under the terms of the GNU General Public License as published by  *
- *   the Free Software Foundation; either version 2 of the License, or     *
- *   (at your option) any later version.                                   *
- *                                                                         *
- *   This program is distributed in the hope that it will be useful,       *
- *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
- *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
- *   GNU General Public License for more details.                          *
- *                                                                         *
- *   You should have received a copy of the GNU General Public License     *
- *   along with this program; if not, write to the                         *
- *   Free Software Foundation, Inc.,                                       *
- *   51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA .        *
- ***************************************************************************/
+/*
+ *   SPDX-FileCopyrightText: 2012 Matthias Fuchs <mat69@gmx.net>
+ *
+ *   SPDX-License-Identifier: GPL-2.0-or-later
+ */
 
 #include "comicdata.h"
 
-#include <Plasma/Theme>
 #include <KLocalizedString>
+#include <Plasma/Theme>
 // Qt
 #include <QPainter>
 
@@ -44,7 +31,7 @@ void ComicData::load()
 
 void ComicData::save()
 {
-    mCfg.writeEntry(QLatin1String("scaleToContent_") + mId,  mScaleComic);
+    mCfg.writeEntry(QLatin1String("scaleToContent_") + mId, mScaleComic);
     mCfg.writeEntry(QLatin1String("maxStripNum_") + mId, mMaxStripNum);
     mCfg.writeEntry(QLatin1String("storedPosition_") + id(), mStored);
 
@@ -86,9 +73,9 @@ void ComicData::setData(const Plasma::DataEngine::Data &data)
     mTitle = data[QStringLiteral("Title")].toString();
 
     const QString suffixType = data[QStringLiteral("SuffixType")].toString();
-    if ( suffixType == QLatin1String("Date")) {
+    if (suffixType == QLatin1String("Date")) {
         mType = Date;
-    } else if ( suffixType == QLatin1String("Number")) {
+    } else if (suffixType == QLatin1String("Number")) {
         mType = Number;
     } else {
         mType = String;
@@ -97,16 +84,16 @@ void ComicData::setData(const Plasma::DataEngine::Data &data)
     QString temp = data[QStringLiteral("Identifier")].toString();
     mCurrent = temp.remove(mId + QLatin1Char(':'));
 
-    //found a new last identifier
+    // found a new last identifier
     if (!hasNext()) {
         mLast = mCurrent;
     }
 
     mCurrentReadable.clear();
-    if ( mType == Number ) {
+    if (mType == Number) {
         mCurrentReadable = i18nc("an abbreviation for Number", "# %1", mCurrent);
         int tempNum = mCurrent.toInt();
-        if ( mMaxStripNum < tempNum ) {
+        if (mMaxStripNum < tempNum) {
             mMaxStripNum = tempNum;
         }
 
@@ -114,7 +101,7 @@ void ComicData::setData(const Plasma::DataEngine::Data &data)
         mFirstStripNum = temp.toInt();
     } else if (mType == Date && QDate::fromString(temp, QStringLiteral("yyyy-MM-dd")).isValid()) {
         mCurrentReadable = mCurrent;
-    } else if ( mType == String ) {
+    } else if (mType == String) {
         mCurrentReadable = mCurrent;
     }
 
@@ -126,16 +113,19 @@ void ComicData::setData(const Plasma::DataEngine::Data &data)
 
 void ComicData::createErrorPicture(const Plasma::DataEngine::Data &data)
 {
-    QPixmap errorPic( 500, 400 );
+    QPixmap errorPic(500, 400);
     errorPic.fill();
-    QPainter p( &errorPic );
+    QPainter p(&errorPic);
     QFont font = QGuiApplication::font();
-    font.setPointSize( 24 );
-    p.setPen( QColor( 0, 0, 0 ) );
-    p.setFont( font );
-    QString title = i18n( "Getting comic strip failed:" );
-    p.drawText( QRect( 10, 10 , 480, 100 ), Qt::TextWordWrap | Qt::AlignHCenter | Qt::AlignVCenter, title );
-    QString text = i18n( "Maybe there is no Internet connection.\nMaybe the comic plugin is broken.\nAnother reason might be that there is no comic for this day/number/string, so choosing a different one might work." );
+    font.setPointSize(24);
+    p.setPen(QColor(0, 0, 0));
+    p.setFont(font);
+    QString title = i18n("Getting comic strip failed:");
+    p.drawText(QRect(10, 10, 480, 100), Qt::TextWordWrap | Qt::AlignHCenter | Qt::AlignVCenter, title);
+    QString text = i18n(
+        "Maybe there is no Internet connection.\nMaybe the comic plugin is broken.\n"
+        "Another reason might be that there is no comic for this day/number/string, "
+        "so choosing a different one might work.");
 
     mPrev = data[QStringLiteral("Previous identifier suffix")].toString();
     if (hasPrev()) {
@@ -143,12 +133,12 @@ void ComicData::createErrorPicture(const Plasma::DataEngine::Data &data)
         if (!identifier.isEmpty()) {
             mErrorStrip = identifier;
         }
-        text.append( i18n( "\n\nChoose the previous strip to go to the last cached strip." ) );
+        text.append(i18n("\n\nChoose the previous strip to go to the last cached strip."));
     }
 
-    font.setPointSize( 16 );
-    p.setFont( font );
-    p.drawText( QRect( 10, 120 , 480, 270 ), Qt::TextWordWrap | Qt::AlignLeft, text );
+    font.setPointSize(16);
+    p.setFont(font);
+    p.drawText(QRect(10, 120, 480, 270), Qt::TextWordWrap | Qt::AlignLeft, text);
 
     mImage = errorPic.toImage();
     mAdditionalText = title + text;
