@@ -15,6 +15,8 @@
 
 #include <cmath>
 
+K_EXPORT_PLASMA_RUNNER_WITH_JSON(ConverterRunner, "plasma-runner-converter.json")
+
 ConverterRunner::ConverterRunner(QObject *parent, const KPluginMetaData &metaData, const QVariantList &args)
     : Plasma::AbstractRunner(parent, metaData, args)
 {
@@ -42,7 +44,7 @@ void ConverterRunner::init()
 
     insertCompatibleUnits();
 
-    actionList = {addAction(QStringLiteral("copy-unit"), QIcon::fromTheme(QStringLiteral("edit-copy")), i18n("Copy unit and number"))};
+    actionList = {new QAction(QIcon::fromTheme(QStringLiteral("edit-copy")), i18n("Copy unit and number"), this)};
     setMinLetterCount(2);
     setMatchRegex(valueRegex);
 }
@@ -98,7 +100,6 @@ void ConverterRunner::match(Plasma::RunnerContext &context)
         match.setType(Plasma::QueryMatch::HelperMatch);
         match.setIconName(QStringLiteral("accessories-calculator"));
         if (outputUnit.categoryId() == KUnitConversion::CurrencyCategory) {
-            outputValue.round(2);
             match.setText(QStringLiteral("%1 (%2)").arg(outputValue.toString(0, 'f', 2), outputUnit.symbol()));
         } else {
             match.setText(QStringLiteral("%1 (%2)").arg(outputValue.toString(), outputUnit.symbol()));
@@ -225,3 +226,4 @@ void ConverterRunner::insertCompatibleUnits()
         }
     }
 }
+#include "converterrunner.moc"
